# stylelens-feature
This is a API document for Object Detection on fashion items\"

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 0.0.1
- Package version: 1.0.0
- Build package: io.swagger.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com//.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com//.git`)

Then import the package:
```python
import stylelens_feature 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import stylelens_feature
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import stylelens_feature
from stylelens_feature.rest import ApiException
from pprint import pprint
# create an instance of the API class
api_instance = stylelens_feature.DetectApi()
file = '/path/to/file.txt' # file | Image file to upload (only support jpg format yet) (optional)

try:
    # Query to detect obejects in the image you sent
    api_response = api_instance.detect_objects(file=file)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling DetectApi->detect_objects: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://objdetect.stylelens.io*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DetectApi* | [**detect_objects**](docs/DetectApi.md#detect_objects) | **POST** / | Query to detect obejects in the image you sent


## Documentation For Models

 - [BoxArray](docs/BoxArray.md)
 - [BoxObject](docs/BoxObject.md)
 - [BoxesArray](docs/BoxesArray.md)
 - [DetectObjectsResponse](docs/DetectObjectsResponse.md)
 - [DetectObjectsResponseData](docs/DetectObjectsResponseData.md)


## Documentation For Authorization


## api_key

- **Type**: API key
- **API key parameter name**: api_key
- **Location**: HTTP header


## Author

devops@bluehack.net

